@@ -44,12 +44,12 @@ LockScreen::LockScreen()
     m_View->setFixedSize(800, 480);
 
     m_WasPortrait = LsWidget::isPortrait();
-    m_isCallActive = false;
+    m_isDialogActive = false;
     createWidgets();
 
 #ifdef Q_WS_MAEMO_5
     QDBusConnection conn = QDBusConnection::systemBus();
-    conn.connect(QString(), MCE_SIGNAL_PATH, MCE_SIGNAL_IF,
+    conn.connect("", MCE_SIGNAL_PATH, MCE_SIGNAL_IF,
                  MCE_DISPLAY_SIG, this, SLOT(onDisplayStateChangedSlot(QString)));
 
     conn.connect("",
@@ -62,9 +62,16 @@ LockScreen::LockScreen()
                  MCE_SIGNAL_IF,
                  MCE_CALL_STATE_SIG, this, SLOT(onCallStateChanged(QString)));
 
-    conn.connect("com.nokia.csd.Call", "/com/nokia/csd/call", "com.nokia.csd.Call",
+    conn.connect("com.nokia.csd.Call",
+                 "/com/nokia/csd/call",
+                 "com.nokia.csd.Call",
                  "Coming", this, SLOT(onIncomingCallSlot(QDBusMessage)));
 
+    conn.connect("com.nokia.system_ui",
+                 "/com/nokia/system_ui/signal",
+                 "com.nokia.system_ui.signal",
+                 "alarm_dialog_status", this, SLOT(onAlarmDialogStatusChanged(QDBusMessage)));
+
     QString orientation = QSettings().value("Main/Orientation", "Auto").toString().toLower();
     if (orientation == "landscape"){
         m_View->setAttribute(Qt::WA_Maemo5LandscapeOrientation);
@@ -103,7 +110,6 @@ void LockScreen::setHildonFlags()
     enable = 1;
     Atom winNTAtom = XInternAtom(QX11Info::display(), "_HILDON_WM_ACTION_NO_TRANSITIONS", false);
     XChangeProperty(QX11Info::display(), m_View->winId(), winNTAtom, XA_CARDINAL, 32, PropModeReplace, (uchar*) &enable, 1);
-
 #endif
 }
 
@@ -208,7 +214,7 @@ void LockScreen::onDisplayStateChangedSlot(QString displayState)
     if (displayState == QLatin1String(MCE_DISPLAY_OFF_STRING)) {
         stopUpdate();
     }else if (displayState == QLatin1String(MCE_DISPLAY_ON_STRING)) {
-        if (m_tklockState == MCE_TK_LOCKED && !m_isCallActive){
+        if (m_tklockState == MCE_TK_LOCKED && !m_isDialogActive){
             onOrientationChanged(0);
             startUpdate();            
         }
@@ -227,7 +233,7 @@ void LockScreen::onTkLockChanged(QString locked)
     if (locked == MCE_TK_UNLOCKED) {
         m_View->hide();
         stopUpdate();
-    } else if (locked == MCE_TK_LOCKED && !m_isCallActive) {
+    } else if (locked == MCE_TK_LOCKED && !m_isDialogActive) {
         if (show())
             startUpdate();
     }
@@ -239,15 +245,29 @@ void LockScreen::onCallStateChanged(QString state)
     qDebug() << "Call state changed:" << state;
 #ifdef Q_WS_MAEMO_5
     if (state != MCE_CALL_STATE_NONE)
-        m_isCallActive = true;
+        m_isDialogActive = true;
     else
-        m_isCallActive = false;
+        m_isDialogActive = false;
 #else
     Q_UNUSED(state)
 #endif
 }
 
 #ifdef Q_WS_MAEMO_5
+void LockScreen::onAlarmDialogStatusChanged(QDBusMessage msg)
+{
+    int status = 0;
+    QVariant val = msg.arguments()[0];
+    status = val.toInt();
+
+    qDebug() << "Alarm dialog status changed" << status;
+    m_isDialogActive = status == 5;
+    if (m_isDialogActive){
+        m_View->hide();
+        stopUpdate();
+    }
+}
+
 void LockScreen::onIncomingCallSlot(QDBusMessage)
 {
     qDebug() << "Incoming call";
