@@ -19,6 +19,7 @@
 #include "lockscreen.h"
 #include <QFile>
 #include <QDir>
+#include <QTranslator>
 #include <iostream>
 
 #define QUOTE_(x) #x
@@ -68,6 +69,12 @@ int main(int argc, char *argv[])
         QFile().copy(":/DefaultSettings.conf", name);
     }
 
+    QString locale = QLocale::system().name();
+    qDebug() << "Locale:" << locale;
+    QTranslator translator;
+    if (translator.load(QString(":/qtlockscreen_%1").arg(locale)))
+        a.installTranslator(&translator);
+
     LockScreen l;
 
     if (LockScreen::Debug || LockScreen::isLocked())
