@@ -22,6 +22,12 @@
 LsWidget::LsWidget(QString name)
 {
     m_Name = name;
+
+    setFlag(QGraphicsItem::ItemIsMovable, false);
+    setFlag(QGraphicsItem::ItemIsSelectable, false);
+    setFlag(QGraphicsItem::ItemIsFocusable, false);
+    setFlag(QGraphicsItem::ItemClipsToShape, true);
+    setFlag(QGraphicsItem::ItemClipsChildrenToShape, true);
 }
 
 QVariant LsWidget::getSetting(QString name, QVariant defaultValue)
@@ -102,6 +108,8 @@ QColor LsWidget::getColorSetting(QString name, QColor defaultValue)
     QStringList elem = color.split(';');
     if (elem.count() == 4)
         return QColor(elem.at(0).toInt(), elem.at(1).toInt(), elem.at(2).toInt(), elem.at(3).toInt());
+    else if (elem.count() == 3)
+        return QColor(elem.at(0).toInt(), elem.at(1).toInt(), elem.at(2).toInt());
     return defaultValue;
 }
 
@@ -191,7 +199,8 @@ void LsWidget::update()
 {
     if (scene() != NULL){
         qDebug() << "Updating widget" << m_Name;
-        scene()->update(sceneRect());
+        //scene()->update(sceneRect());
+        QGraphicsItem::update(boundingRect());
     }
 }
 
